"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getHasManyDirectiveTransformer = void 0;
const has_many_directive_ddb_fields_transformer_1 = require("./has-many-directive-ddb-fields-transformer");
const has_many_directive_sql_transformer_1 = require("./has-many-directive-sql-transformer");
const has_many_directive_ddb_references_transformer_1 = require("./has-many-directive-ddb-references-transformer");
const graphql_transformer_core_1 = require("@aws-amplify/graphql-transformer-core");
const hasManyDirectiveMySqlTransformer = new has_many_directive_sql_transformer_1.HasManyDirectiveSQLTransformer();
const hasManyDirectivePostgresTransformer = new has_many_directive_sql_transformer_1.HasManyDirectiveSQLTransformer();
const hasManyDirectiveDdbFieldsTransformer = new has_many_directive_ddb_fields_transformer_1.HasManyDirectiveDDBFieldsTransformer();
const hasManyDirectiveDdbReferencesTransformer = new has_many_directive_ddb_references_transformer_1.HasManyDirectiveDDBReferencesTransformer();
const getHasManyDirectiveTransformer = (dbType, config) => {
    switch (dbType) {
        case 'MYSQL':
            return hasManyDirectiveMySqlTransformer;
        case 'POSTGRES':
            return hasManyDirectivePostgresTransformer;
        case 'DYNAMODB':
            if (config.references) {
                if (config.fields) {
                    throw new graphql_transformer_core_1.InvalidDirectiveError(`fields and references cannot be defined in the same ${config.directiveName}. Use 'references'`);
                }
                if (config.references.length < 1) {
                    throw new graphql_transformer_core_1.InvalidDirectiveError(`Invalid @hasMany directive on ${config.field.name.value} - empty references list`);
                }
                return hasManyDirectiveDdbReferencesTransformer;
            }
            return hasManyDirectiveDdbFieldsTransformer;
    }
};
exports.getHasManyDirectiveTransformer = getHasManyDirectiveTransformer;
//# sourceMappingURL=has-many-directive-transformer-factory.js.map